spacepy.toolbox.savepickle — SpacePy v0.1.5 Manual

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- toolbox - Toolbox of various functions and generic utilities »

# spacepy.toolbox.savepickle

`spacepy.toolbox.` `savepickle`(fln, dict, compress=None)

  save dictionary variable dict to a pickle with filename fln

  Parameters: | fln : string filename dict : dict container with stuff compress : bool write as a gzip-compressed file (.gz will be added to L{fln}). If not specified, defaults to uncompressed, unless the compressed file exists and the uncompressed does not.

  See also

  `loadpickle`

  Examples

      >>> d = {'grade':[1,2,3], 'name':['Mary', 'John', 'Chris']}
      >>> savepickle('test.pbin', d)

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- toolbox - Toolbox of various functions and generic utilities »